pub struct Framed<T, U> { /* private fields */ }
A unified Stream and Sink interface to an underlying I/O object, using the Encoder and Decoder traits to encode and decode frames.

Raw I/O objects work with byte sequences, but higher-level code usually wants to batch these into meaningful chunks, called “frames”. This method layers framing on top of an I/O object, by using the Encoder/Decoder traits to handle encoding and decoding of message frames. Note that the incoming and outgoing frame types may be distinct.

Implementations

This function returns a single object that is both Stream and Sink; grouping this into a single object is often useful for layering things like gzip or TLS, which require both read and write access to the underlying object.

Returns a reference to the underlying codec.

Returns a mutable reference to the underlying codec.

Returns a reference to the underlying I/O stream wrapped by Frame.

Note that care should be taken to not tamper with the underlying stream of data coming in as it may corrupt the stream of frames otherwise being worked with.

Returns a mutable reference to the underlying I/O stream.

Note that care should be taken to not tamper with the underlying stream of data coming in as it may corrupt the stream of frames otherwise being worked with.

Returns a Pin of a mutable reference to the underlying I/O stream.

Check if read buffer is empty.

Check if write buffer is empty.

Check if write buffer is full.

Check if framed is able to write more data.

Framed object considers ready if there is free space in write buffer.

Consume the Frame, returning Frame with different codec.

Consume the Frame, returning Frame with different io.

Consume the Frame, returning Frame with different codec.

Serialize item and write to the inner buffer

Try to read underlying I/O stream and decode item.

Flush write buffer to underlying I/O stream.

Flush write buffer and shutdown underlying I/O stream.

This function returns a single object that is both Stream and Sink; grouping this into a single object is often useful for layering things like gzip or TLS, which require both read and write access to the underlying object.

These objects take a stream, a read buffer and a write buffer. These fields can be obtained from an existing Framed with the into_parts method.

Consumes the Frame, returning its underlying I/O stream, the buffer with unprocessed data, and the codec.

Note that care should be taken to not tamper with the underlying stream of data coming in as it may corrupt the stream of frames otherwise being worked with.